% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/aa_mutmat.R
\name{aa_mutmat}
\alias{aa_mutmat}
\title{Amino acid mutation matrix}
\usage{
aa_mutmat(acc = NA, aaindex = NA, acc_list = FALSE)
}
\arguments{
\item{acc}{Accession id for a specified mutation or contact potential
matrix.}

\item{aaindex}{Database where the requested accession id is locate. The
possible values are:  "aaindex2" or "aaindex3".}

\item{acc_list}{Logical. If TRUE, then the list of available matrices ids
and index names is returned.}
}
\value{
A mutation or contact potential matrix, or the list of available
matrices ids and index names is returned.
}
\description{
This returns an amino acid mutation matrix or a
statistical protein contact potentials matrix from
\href{https://www.genome.jp/aaindex/}{AAindex} (ver.9.2).

The aminoacid similarity matrices from Amino Acid Index Database
\url{https://www.genome.jp/aaindex/} are provided here. AAindex (ver.9.2)
is a database of numerical indices representing various physicochemical and
biochemical properties of amino acids and pairs of amino acids.

The similarity of amino acids can be represented numerically, expressed in
terms of observed mutation rate or physicochemical properties. A similarity
matrix, also called a mutation matrix, is a set of 210 numerical values, 20
diagonal and 20x19/2 off-diagonal elements, used for sequence alignments
and similarity searches.
}
\examples{
## Load the mutation matrices from database from the packages
data("aaindex2", package = "GenomAutomorphism" )

## Get the available mutation matrices
mat <- aa_mutmat(aaindex = aaindex2, acc_list = TRUE)
mat[1:10]

## Return the 'Base-substitution-protein-stability matrix 
## (Miyazawa-Jernigan, 1993)'
aa_mutmat(acc = "MIYS930101", aaindex = aaindex2)

## Return the 'BLOSUM80 substitution matrix (Henikoff-Henikoff, 1992)'
aa_mutmat(acc = "HENS920103", aaindex = aaindex2)

}
\seealso{
\code{\link{aaindex2}}, \code{\link{aaindex3}}, and
\code{\link{get_mutscore}}.
}
\author{
Robersy Sanchez \url{https://genomaths.com}
}
